@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc
-version: 1.17.0.1
-id: pandoc-1.17.0.1-1c6da1ddfcd8a2619fb2ca103a269dd9
-key: pando_Bh2PAPU8nTe47bFaxmXA2O
+version: 1.17.0.3
+id: pandoc-1.17.0.3-a12df7a7745e5ea4de39fe36e7ff7b76
+key: pando_Ic8iW0y3niIE97JSXnLXg8
 license: GPL
-copyright: (c) 2006-2015 John MacFarlane
+copyright: (c) 2006-2016 John MacFarlane
 maintainer: John MacFarlane <jgm@berkeley.edu>
 stability: alpha
 homepage: http://pandoc.org
@@ -82,15 +82,15 @@ hidden-modules: Text.Pandoc.Readers.Docx.Lists
                 Text.Pandoc.Compat.Except Text.Pandoc.Compat.TagSoupEntity
                 Text.Pandoc.Compat.Directory Text.Pandoc.Compat.Monoid Paths_pandoc
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.1
+import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 data-dir: /usr/share/pandoc
-hs-libraries: HSpandoc-1.17.0.1-Bh2PAPU8nTe47bFaxmXA2O
+hs-libraries: HSpandoc-1.17.0.3-Ic8iW0y3niIE97JSXnLXg8
 depends:
     HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
     JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -98,7 +98,7 @@ depends:
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    cmark-0.5.1-361c8054de5c13037742ba8477e3ace4
+    cmark-0.5.2-f48a7256a8c75efe8918f0ce1d08f0cd
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
@@ -117,7 +117,7 @@ depends:
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
-    pandoc-types-1.16.1-0b1608b10c9621b9412cccf92ea53ad6
+    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
@@ -125,13 +125,13 @@ depends:
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
     temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
-    texmath-0.8.5-aa2be80ae996b0529501af10b92dc849
+    texmath-0.8.5.1-12fde9597135cf71aeccebd23ab95779
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
-    yaml-0.8.16-8e3a1d884bd629b7e4f9063e0e319626
+    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
     zip-archive-0.3-2c98cfc50f306ecd4e01363be7a8d981
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
